"""Common configuration constants
"""

PROJECTNAME = 'Products.categorynavigator'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'CategoryNavigator': 'Products.categorynavigator: Add Category Navigator',
}
